Intercepts standard likelihood and residual-based generics that are not directly applicable to post-linkage models because the true match status remains latent.
Usage
# S3 method for class 'plmodel'
logLik(object, ...)
# S3 method for class 'plmodel'
profile(fitted, ...)
# S3 method for class 'plmodel'
anova(object, ...)
# S3 method for class 'plmodel'
extractAIC(fit, scale, k = 2, ...)
# S3 method for class 'plglm'
cooks.distance(model, ...)
# S3 method for class 'plglm'
rstudent(model, ...)